@@ -1,7 +1,7 @@
 """
 Type annotations for elb service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/literals/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/literals/)
 
 Usage::
 
@@ -260,6 +260,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
