@@ -1,7 +1,7 @@
 """
 Type annotations for elb service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/type_defs/)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence
 
-from typing_extensions import NotRequired
-
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -51,10 +49,15 @@ __all__ = (
     "DeleteLoadBalancerPolicyInputRequestTypeDef",
     "DeregisterEndPointsInputRequestTypeDef",
     "DeregisterEndPointsOutputTypeDef",
+    "DescribeAccessPointsInputDescribeLoadBalancersPaginateTypeDef",
     "DescribeAccessPointsInputRequestTypeDef",
     "DescribeAccessPointsOutputTypeDef",
+    "DescribeAccountLimitsInputDescribeAccountLimitsPaginateTypeDef",
     "DescribeAccountLimitsInputRequestTypeDef",
     "DescribeAccountLimitsOutputTypeDef",
+    "DescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef",
+    "DescribeEndPointStateInputInstanceDeregisteredWaitTypeDef",
+    "DescribeEndPointStateInputInstanceInServiceWaitTypeDef",
     "DescribeEndPointStateInputRequestTypeDef",
     "DescribeEndPointStateOutputTypeDef",
     "DescribeLoadBalancerAttributesInputRequestTypeDef",
@@ -101,15 +104,26 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
-AccessLogTypeDef = TypedDict(
-    "AccessLogTypeDef",
+_RequiredAccessLogTypeDef = TypedDict(
+    "_RequiredAccessLogTypeDef",
     {
         "Enabled": bool,
-        "S3BucketName": NotRequired[str],
-        "EmitInterval": NotRequired[int],
-        "S3BucketPrefix": NotRequired[str],
     },
 )
+_OptionalAccessLogTypeDef = TypedDict(
+    "_OptionalAccessLogTypeDef",
+    {
+        "S3BucketName": str,
+        "EmitInterval": int,
+        "S3BucketPrefix": str,
+    },
+    total=False,
+)
+
+
+class AccessLogTypeDef(_RequiredAccessLogTypeDef, _OptionalAccessLogTypeDef):
+    pass
+
 
 AddAvailabilityZonesInputRequestTypeDef = TypedDict(
     "AddAvailabilityZonesInputRequestTypeDef",
@@ -138,17 +152,19 @@ AddTagsInputRequestTypeDef = TypedDict(
 AdditionalAttributeTypeDef = TypedDict(
     "AdditionalAttributeTypeDef",
     {
-        "Key": NotRequired[str],
-        "Value": NotRequired[str],
+        "Key": str,
+        "Value": str,
     },
+    total=False,
 )
 
 AppCookieStickinessPolicyTypeDef = TypedDict(
     "AppCookieStickinessPolicyTypeDef",
     {
-        "PolicyName": NotRequired[str],
-        "CookieName": NotRequired[str],
+        "PolicyName": str,
+        "CookieName": str,
     },
+    total=False,
 )
 
 ApplySecurityGroupsToLoadBalancerInputRequestTypeDef = TypedDict(
@@ -186,9 +202,10 @@ AttachLoadBalancerToSubnetsOutputTypeDef = TypedDict(
 BackendServerDescriptionTypeDef = TypedDict(
     "BackendServerDescriptionTypeDef",
     {
-        "InstancePort": NotRequired[int],
-        "PolicyNames": NotRequired[List[str]],
+        "InstancePort": int,
+        "PolicyNames": List[str],
     },
+    total=False,
 )
 
 ConfigureHealthCheckInputRequestTypeDef = TypedDict(
@@ -207,13 +224,26 @@ ConfigureHealthCheckOutputTypeDef = TypedDict(
     },
 )
 
-ConnectionDrainingTypeDef = TypedDict(
-    "ConnectionDrainingTypeDef",
+_RequiredConnectionDrainingTypeDef = TypedDict(
+    "_RequiredConnectionDrainingTypeDef",
     {
         "Enabled": bool,
-        "Timeout": NotRequired[int],
     },
 )
+_OptionalConnectionDrainingTypeDef = TypedDict(
+    "_OptionalConnectionDrainingTypeDef",
+    {
+        "Timeout": int,
+    },
+    total=False,
+)
+
+
+class ConnectionDrainingTypeDef(
+    _RequiredConnectionDrainingTypeDef, _OptionalConnectionDrainingTypeDef
+):
+    pass
+
 
 ConnectionSettingsTypeDef = TypedDict(
     "ConnectionSettingsTypeDef",
@@ -222,18 +252,31 @@ ConnectionSettingsTypeDef = TypedDict(
     },
 )
 
-CreateAccessPointInputRequestTypeDef = TypedDict(
-    "CreateAccessPointInputRequestTypeDef",
+_RequiredCreateAccessPointInputRequestTypeDef = TypedDict(
+    "_RequiredCreateAccessPointInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "Listeners": Sequence["ListenerTypeDef"],
-        "AvailabilityZones": NotRequired[Sequence[str]],
-        "Subnets": NotRequired[Sequence[str]],
-        "SecurityGroups": NotRequired[Sequence[str]],
-        "Scheme": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateAccessPointInputRequestTypeDef = TypedDict(
+    "_OptionalCreateAccessPointInputRequestTypeDef",
+    {
+        "AvailabilityZones": Sequence[str],
+        "Subnets": Sequence[str],
+        "SecurityGroups": Sequence[str],
+        "Scheme": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateAccessPointInputRequestTypeDef(
+    _RequiredCreateAccessPointInputRequestTypeDef, _OptionalCreateAccessPointInputRequestTypeDef
+):
+    pass
+
 
 CreateAccessPointOutputTypeDef = TypedDict(
     "CreateAccessPointOutputTypeDef",
@@ -252,14 +295,28 @@ CreateAppCookieStickinessPolicyInputRequestTypeDef = TypedDict(
     },
 )
 
-CreateLBCookieStickinessPolicyInputRequestTypeDef = TypedDict(
-    "CreateLBCookieStickinessPolicyInputRequestTypeDef",
+_RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef = TypedDict(
+    "_RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyName": str,
-        "CookieExpirationPeriod": NotRequired[int],
     },
 )
+_OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef = TypedDict(
+    "_OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef",
+    {
+        "CookieExpirationPeriod": int,
+    },
+    total=False,
+)
+
+
+class CreateLBCookieStickinessPolicyInputRequestTypeDef(
+    _RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef,
+    _OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef,
+):
+    pass
+
 
 CreateLoadBalancerListenerInputRequestTypeDef = TypedDict(
     "CreateLoadBalancerListenerInputRequestTypeDef",
@@ -269,15 +326,29 @@ CreateLoadBalancerListenerInputRequestTypeDef = TypedDict(
     },
 )
 
-CreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
-    "CreateLoadBalancerPolicyInputRequestTypeDef",
+_RequiredCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
+    "_RequiredCreateLoadBalancerPolicyInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyName": str,
         "PolicyTypeName": str,
-        "PolicyAttributes": NotRequired[Sequence["PolicyAttributeTypeDef"]],
     },
 )
+_OptionalCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
+    "_OptionalCreateLoadBalancerPolicyInputRequestTypeDef",
+    {
+        "PolicyAttributes": Sequence["PolicyAttributeTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLoadBalancerPolicyInputRequestTypeDef(
+    _RequiredCreateLoadBalancerPolicyInputRequestTypeDef,
+    _OptionalCreateLoadBalancerPolicyInputRequestTypeDef,
+):
+    pass
+
 
 CrossZoneLoadBalancingTypeDef = TypedDict(
     "CrossZoneLoadBalancingTypeDef",
@@ -325,13 +396,23 @@ DeregisterEndPointsOutputTypeDef = TypedDict(
     },
 )
 
+DescribeAccessPointsInputDescribeLoadBalancersPaginateTypeDef = TypedDict(
+    "DescribeAccessPointsInputDescribeLoadBalancersPaginateTypeDef",
+    {
+        "LoadBalancerNames": Sequence[str],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 DescribeAccessPointsInputRequestTypeDef = TypedDict(
     "DescribeAccessPointsInputRequestTypeDef",
     {
-        "LoadBalancerNames": NotRequired[Sequence[str]],
-        "Marker": NotRequired[str],
-        "PageSize": NotRequired[int],
+        "LoadBalancerNames": Sequence[str],
+        "Marker": str,
+        "PageSize": int,
     },
+    total=False,
 )
 
 DescribeAccessPointsOutputTypeDef = TypedDict(
@@ -343,12 +424,21 @@ DescribeAccessPointsOutputTypeDef = TypedDict(
     },
 )
 
+DescribeAccountLimitsInputDescribeAccountLimitsPaginateTypeDef = TypedDict(
+    "DescribeAccountLimitsInputDescribeAccountLimitsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 DescribeAccountLimitsInputRequestTypeDef = TypedDict(
     "DescribeAccountLimitsInputRequestTypeDef",
     {
-        "Marker": NotRequired[str],
-        "PageSize": NotRequired[int],
+        "Marker": str,
+        "PageSize": int,
     },
+    total=False,
 )
 
 DescribeAccountLimitsOutputTypeDef = TypedDict(
@@ -360,13 +450,96 @@ DescribeAccountLimitsOutputTypeDef = TypedDict(
     },
 )
 
-DescribeEndPointStateInputRequestTypeDef = TypedDict(
-    "DescribeEndPointStateInputRequestTypeDef",
+_RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef",
     {
         "LoadBalancerName": str,
-        "Instances": NotRequired[Sequence["InstanceTypeDef"]],
     },
 )
+_OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef",
+    {
+        "Instances": Sequence["InstanceTypeDef"],
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef(
+    _RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef,
+    _OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef,
+):
+    pass
+
+
+_RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef",
+    {
+        "LoadBalancerName": str,
+    },
+)
+_OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef",
+    {
+        "Instances": Sequence["InstanceTypeDef"],
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeEndPointStateInputInstanceDeregisteredWaitTypeDef(
+    _RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef,
+    _OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef,
+):
+    pass
+
+
+_RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef",
+    {
+        "LoadBalancerName": str,
+    },
+)
+_OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef",
+    {
+        "Instances": Sequence["InstanceTypeDef"],
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeEndPointStateInputInstanceInServiceWaitTypeDef(
+    _RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef,
+    _OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef,
+):
+    pass
+
+
+_RequiredDescribeEndPointStateInputRequestTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputRequestTypeDef",
+    {
+        "LoadBalancerName": str,
+    },
+)
+_OptionalDescribeEndPointStateInputRequestTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputRequestTypeDef",
+    {
+        "Instances": Sequence["InstanceTypeDef"],
+    },
+    total=False,
+)
+
+
+class DescribeEndPointStateInputRequestTypeDef(
+    _RequiredDescribeEndPointStateInputRequestTypeDef,
+    _OptionalDescribeEndPointStateInputRequestTypeDef,
+):
+    pass
+
 
 DescribeEndPointStateOutputTypeDef = TypedDict(
     "DescribeEndPointStateOutputTypeDef",
@@ -394,9 +567,10 @@ DescribeLoadBalancerAttributesOutputTypeDef = TypedDict(
 DescribeLoadBalancerPoliciesInputRequestTypeDef = TypedDict(
     "DescribeLoadBalancerPoliciesInputRequestTypeDef",
     {
-        "LoadBalancerName": NotRequired[str],
-        "PolicyNames": NotRequired[Sequence[str]],
+        "LoadBalancerName": str,
+        "PolicyNames": Sequence[str],
     },
+    total=False,
 )
 
 DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
@@ -410,8 +584,9 @@ DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
 DescribeLoadBalancerPolicyTypesInputRequestTypeDef = TypedDict(
     "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
     {
-        "PolicyTypeNames": NotRequired[Sequence[str]],
+        "PolicyTypeNames": Sequence[str],
     },
+    total=False,
 )
 
 DescribeLoadBalancerPolicyTypesOutputTypeDef = TypedDict(
@@ -467,86 +642,104 @@ HealthCheckTypeDef = TypedDict(
 InstanceStateTypeDef = TypedDict(
     "InstanceStateTypeDef",
     {
-        "InstanceId": NotRequired[str],
-        "State": NotRequired[str],
-        "ReasonCode": NotRequired[str],
-        "Description": NotRequired[str],
+        "InstanceId": str,
+        "State": str,
+        "ReasonCode": str,
+        "Description": str,
     },
+    total=False,
 )
 
 InstanceTypeDef = TypedDict(
     "InstanceTypeDef",
     {
-        "InstanceId": NotRequired[str],
+        "InstanceId": str,
     },
+    total=False,
 )
 
 LBCookieStickinessPolicyTypeDef = TypedDict(
     "LBCookieStickinessPolicyTypeDef",
     {
-        "PolicyName": NotRequired[str],
-        "CookieExpirationPeriod": NotRequired[int],
+        "PolicyName": str,
+        "CookieExpirationPeriod": int,
     },
+    total=False,
 )
 
 LimitTypeDef = TypedDict(
     "LimitTypeDef",
     {
-        "Name": NotRequired[str],
-        "Max": NotRequired[str],
+        "Name": str,
+        "Max": str,
     },
+    total=False,
 )
 
 ListenerDescriptionTypeDef = TypedDict(
     "ListenerDescriptionTypeDef",
     {
-        "Listener": NotRequired["ListenerTypeDef"],
-        "PolicyNames": NotRequired[List[str]],
+        "Listener": "ListenerTypeDef",
+        "PolicyNames": List[str],
     },
+    total=False,
 )
 
-ListenerTypeDef = TypedDict(
-    "ListenerTypeDef",
+_RequiredListenerTypeDef = TypedDict(
+    "_RequiredListenerTypeDef",
     {
         "Protocol": str,
         "LoadBalancerPort": int,
         "InstancePort": int,
-        "InstanceProtocol": NotRequired[str],
-        "SSLCertificateId": NotRequired[str],
     },
 )
+_OptionalListenerTypeDef = TypedDict(
+    "_OptionalListenerTypeDef",
+    {
+        "InstanceProtocol": str,
+        "SSLCertificateId": str,
+    },
+    total=False,
+)
+
+
+class ListenerTypeDef(_RequiredListenerTypeDef, _OptionalListenerTypeDef):
+    pass
+
 
 LoadBalancerAttributesTypeDef = TypedDict(
     "LoadBalancerAttributesTypeDef",
     {
-        "CrossZoneLoadBalancing": NotRequired["CrossZoneLoadBalancingTypeDef"],
-        "AccessLog": NotRequired["AccessLogTypeDef"],
-        "ConnectionDraining": NotRequired["ConnectionDrainingTypeDef"],
-        "ConnectionSettings": NotRequired["ConnectionSettingsTypeDef"],
-        "AdditionalAttributes": NotRequired[List["AdditionalAttributeTypeDef"]],
+        "CrossZoneLoadBalancing": "CrossZoneLoadBalancingTypeDef",
+        "AccessLog": "AccessLogTypeDef",
+        "ConnectionDraining": "ConnectionDrainingTypeDef",
+        "ConnectionSettings": "ConnectionSettingsTypeDef",
+        "AdditionalAttributes": List["AdditionalAttributeTypeDef"],
     },
+    total=False,
 )
 
 LoadBalancerDescriptionTypeDef = TypedDict(
     "LoadBalancerDescriptionTypeDef",
     {
-        "LoadBalancerName": NotRequired[str],
-        "DNSName": NotRequired[str],
-        "CanonicalHostedZoneName": NotRequired[str],
-        "CanonicalHostedZoneNameID": NotRequired[str],
-        "ListenerDescriptions": NotRequired[List["ListenerDescriptionTypeDef"]],
-        "Policies": NotRequired["PoliciesTypeDef"],
-        "BackendServerDescriptions": NotRequired[List["BackendServerDescriptionTypeDef"]],
-        "AvailabilityZones": NotRequired[List[str]],
-        "Subnets": NotRequired[List[str]],
-        "VPCId": NotRequired[str],
-        "Instances": NotRequired[List["InstanceTypeDef"]],
-        "HealthCheck": NotRequired["HealthCheckTypeDef"],
-        "SourceSecurityGroup": NotRequired["SourceSecurityGroupTypeDef"],
-        "SecurityGroups": NotRequired[List[str]],
-        "CreatedTime": NotRequired[datetime],
-        "Scheme": NotRequired[str],
+        "LoadBalancerName": str,
+        "DNSName": str,
+        "CanonicalHostedZoneName": str,
+        "CanonicalHostedZoneNameID": str,
+        "ListenerDescriptions": List["ListenerDescriptionTypeDef"],
+        "Policies": "PoliciesTypeDef",
+        "BackendServerDescriptions": List["BackendServerDescriptionTypeDef"],
+        "AvailabilityZones": List[str],
+        "Subnets": List[str],
+        "VPCId": str,
+        "Instances": List["InstanceTypeDef"],
+        "HealthCheck": "HealthCheckTypeDef",
+        "SourceSecurityGroup": "SourceSecurityGroupTypeDef",
+        "SecurityGroups": List[str],
+        "CreatedTime": datetime,
+        "Scheme": str,
     },
+    total=False,
 )
 
 ModifyLoadBalancerAttributesInputRequestTypeDef = TypedDict(
@@ -569,66 +762,71 @@ ModifyLoadBalancerAttributesOutputTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PoliciesTypeDef = TypedDict(
     "PoliciesTypeDef",
     {
-        "AppCookieStickinessPolicies": NotRequired[List["AppCookieStickinessPolicyTypeDef"]],
-        "LBCookieStickinessPolicies": NotRequired[List["LBCookieStickinessPolicyTypeDef"]],
-        "OtherPolicies": NotRequired[List[str]],
+        "AppCookieStickinessPolicies": List["AppCookieStickinessPolicyTypeDef"],
+        "LBCookieStickinessPolicies": List["LBCookieStickinessPolicyTypeDef"],
+        "OtherPolicies": List[str],
     },
+    total=False,
 )
 
 PolicyAttributeDescriptionTypeDef = TypedDict(
     "PolicyAttributeDescriptionTypeDef",
     {
-        "AttributeName": NotRequired[str],
-        "AttributeValue": NotRequired[str],
+        "AttributeName": str,
+        "AttributeValue": str,
     },
+    total=False,
 )
 
 PolicyAttributeTypeDef = TypedDict(
     "PolicyAttributeTypeDef",
     {
-        "AttributeName": NotRequired[str],
-        "AttributeValue": NotRequired[str],
+        "AttributeName": str,
+        "AttributeValue": str,
     },
+    total=False,
 )
 
 PolicyAttributeTypeDescriptionTypeDef = TypedDict(
     "PolicyAttributeTypeDescriptionTypeDef",
     {
-        "AttributeName": NotRequired[str],
-        "AttributeType": NotRequired[str],
-        "Description": NotRequired[str],
-        "DefaultValue": NotRequired[str],
-        "Cardinality": NotRequired[str],
+        "AttributeName": str,
+        "AttributeType": str,
+        "Description": str,
+        "DefaultValue": str,
+        "Cardinality": str,
     },
+    total=False,
 )
 
 PolicyDescriptionTypeDef = TypedDict(
     "PolicyDescriptionTypeDef",
     {
-        "PolicyName": NotRequired[str],
-        "PolicyTypeName": NotRequired[str],
-        "PolicyAttributeDescriptions": NotRequired[List["PolicyAttributeDescriptionTypeDef"]],
+        "PolicyName": str,
+        "PolicyTypeName": str,
+        "PolicyAttributeDescriptions": List["PolicyAttributeDescriptionTypeDef"],
     },
+    total=False,
 )
 
 PolicyTypeDescriptionTypeDef = TypedDict(
     "PolicyTypeDescriptionTypeDef",
     {
-        "PolicyTypeName": NotRequired[str],
-        "Description": NotRequired[str],
-        "PolicyAttributeTypeDescriptions": NotRequired[
-            List["PolicyAttributeTypeDescriptionTypeDef"]
-        ],
+        "PolicyTypeName": str,
+        "Description": str,
+        "PolicyAttributeTypeDescriptions": List["PolicyAttributeTypeDescriptionTypeDef"],
     },
+    total=False,
 )
 
 RegisterEndPointsInputRequestTypeDef = TypedDict(
@@ -712,38 +910,53 @@ SetLoadBalancerPoliciesOfListenerInputRequestTypeDef = TypedDict(
 SourceSecurityGroupTypeDef = TypedDict(
     "SourceSecurityGroupTypeDef",
     {
-        "OwnerAlias": NotRequired[str],
-        "GroupName": NotRequired[str],
+        "OwnerAlias": str,
+        "GroupName": str,
     },
+    total=False,
 )
 
 TagDescriptionTypeDef = TypedDict(
     "TagDescriptionTypeDef",
     {
-        "LoadBalancerName": NotRequired[str],
-        "Tags": NotRequired[List["TagTypeDef"]],
+        "LoadBalancerName": str,
+        "Tags": List["TagTypeDef"],
     },
+    total=False,
 )
 
 TagKeyOnlyTypeDef = TypedDict(
     "TagKeyOnlyTypeDef",
     {
-        "Key": NotRequired[str],
+        "Key": str,
     },
+    total=False,
 )
 
-TagTypeDef = TypedDict(
-    "TagTypeDef",
+_RequiredTagTypeDef = TypedDict(
+    "_RequiredTagTypeDef",
     {
         "Key": str,
-        "Value": NotRequired[str],
     },
 )
+_OptionalTagTypeDef = TypedDict(
+    "_OptionalTagTypeDef",
+    {
+        "Value": str,
+    },
+    total=False,
+)
+
+
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+    pass
+
 
 WaiterConfigTypeDef = TypedDict(
     "WaiterConfigTypeDef",
     {
-        "Delay": NotRequired[int],
-        "MaxAttempts": NotRequired[int],
+        "Delay": int,
+        "MaxAttempts": int,
     },
+    total=False,
 )
